@@ -135,6 +135,7 @@ static void appendResults(const GBFSService &service, const LocationRequest &req
         loc.setIdentifier(service.systemId, stationId);
         loc.setStreetAddress(cleanAddress(station.value(QLatin1String("address")).toString()));
         loc.setPostalCode(station.value(QLatin1String("post_code")).toString());
+        loc.setLocality(station.value(QLatin1String("city")).toString()); // non-standard extension
         // TODO cover more properties
 
         RentalVehicleStation s;
@@ -184,16 +185,26 @@ static void appendResults(const GBFSService &service, const LocationRequest &req
         }
         const auto lat = GBFSReader::readLatitude(bike);
         const auto lon = GBFSReader::readLongitude(bike);
-        if (std::isnan(lat) || std::isnan(lon) || Location::distance(lat, lon, req.latitude(), req.longitude()) > req.maximumDistance()) {
+        const bool selectedByCoord = !std::isnan(lat) && !std::isnan(lon) && Location::distance(lat, lon, req.latitude(), req.longitude()) > req.maximumDistance();
+
+        // GBFS v2.1: docked vehicle status - TODO do we want to drop the corresponding station in that case?
+        const auto id = stationIdToString(bike.value(QLatin1String("station_id")));
+        const auto it = std::find(selectedStationIds.begin(), selectedStationIds.end(), id);
+        if (it == selectedStationIds.end() && !selectedByCoord) {
             continue;
         }
 
         Location loc;
         loc.setName(network.name());
         loc.setType(Location::RentedVehicle);
-        loc.setCoordinate(lat, lon);
-        const auto stationId = bike.value(QLatin1String("bike_id")).toString();
-        loc.setIdentifier(service.systemId, stationId);
+        if (selectedByCoord) {
+            loc.setCoordinate(lat, lon);
+        } else {
+            const auto &station = context->result[context->result.size() - selectedStationIds.size() + std::distance(selectedStationIds.begin(), it)];
+            loc.setCoordinate(station.latitude(), station.longitude());
+        }
+        const auto bikeId = bike.value(QLatin1String("bike_id")).toString();
+        loc.setIdentifier(service.systemId, bikeId);
 
         // TODO deep rental links
         RentalVehicle vehicle;
@@ -205,6 +216,9 @@ static void appendResults(const GBFSService &service, const LocationRequest &req
         }
         const auto vehicleType = vehicleTypes.vehicleType(vehicleTypeId);
         vehicle.setType(gbfs2kptVehicleType(vehicleType));
+        if (!vehicleType.name.isEmpty()) {
+            loc.setName(vehicleType.name);
+        }
 
         const auto range = bike.value(QLatin1String("current_range_meters")).toInt();
         if (range > 0) { // there's too many reporting 0 for unknown that we can assume 0 means actually empty...
